<?php

namespace Drupal\custom_field\Plugin\CustomField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\custom_field\Plugin\CustomFieldFormatterInterface;

/**
 * Plugin implementation of the 'text_default' formatter.
 *
 * @FieldFormatter(
 *   id = "text_default",
 *   label = @Translation("Default"),
 *   field_types = {
 *     "string_long",
 *   }
 * )
 */
class TextDefaultFormatter implements CustomFieldFormatterInterface {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state, array $settings) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function formatValue(array $settings) {
    $output = $settings['value'];
    $widget_settings = $settings['widget_settings'];
    if ($widget_settings['formatted']) {
      // The ProcessedText element already handles cache context & tag bubbling.
      // @see \Drupal\filter\Element\ProcessedText::preRenderText()
      $build = [
        '#type' => 'processed_text',
        '#text' => $settings['value'],
        '#format' => $widget_settings['default_format'],
        '#langcode' => $settings['langcode'],
      ];
      $output = \Drupal::service('renderer')->render($build);
    }

    return $output;
  }

}
