<?php

namespace Drupal\custom_field\Plugin\CustomField\FieldType;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\custom_field\Plugin\CustomFieldTypeBase;

/**
 * Plugin implementation of the 'integer' custom field type.
 *
 * @CustomFieldType(
 *   id = "integer",
 *   label = @Translation("Integer"),
 *   description = @Translation("A custom field integer field type."),
 *   category = @Translation("Number"),
 *   default_widget = "integer",
 *   default_formatter = "number_integer",
 * )
 */
class IntegerType extends CustomFieldTypeBase {

  /**
   * {@inheritdoc}
   */
  public static function schema(array $settings): array {
    return [
      'type' => 'int',
      'size' => $settings['size'] ?? 'normal',
      'unsigned' => $settings['unsigned'] ?? FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(array $settings): DataDefinition {
    return DataDefinition::create('integer')
      ->setLabel(new TranslatableMarkup('%name value', ['%name' => $settings['name']]))
      ->setRequired(FALSE);
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints(array $settings): array {
    $constraints = [];
    if ($settings['unsigned']) {
      $constraints['Range'] = [
        'min' => 0,
        'minMessage' => $this->t('%name: The integer must be larger or equal to %min.', [
          '%name' => $settings['name'],
          '%min' => 0,
        ]),
      ];
    }

    return $constraints;
  }

}
